package com.zehong.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.THiddenTroubleInfoMapper;
import com.zehong.system.domain.THiddenTroubleInfo;
import com.zehong.system.service.ITHiddenTroubleInfoService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 燃气隐患Service业务层处理
 *
 * @author zehong
 * @date 2022-03-24
 */
@Service
public class THiddenTroubleInfoServiceImpl implements ITHiddenTroubleInfoService
{
    @Autowired
    private THiddenTroubleInfoMapper tHiddenTroubleInfoMapper;

    /**
     * 查询燃气隐患
     *
     * @param hiddenTroubleId 燃气隐患ID
     * @return 燃气隐患
     */
    @Override
    public THiddenTroubleInfo selectTHiddenTroubleInfoById(Long hiddenTroubleId)
    {
        return tHiddenTroubleInfoMapper.selectTHiddenTroubleInfoById(hiddenTroubleId);
    }

    /**
     * 查询燃气隐患列表
     *
     * @param tHiddenTroubleInfo 燃气隐患
     * @return 燃气隐患
     */
    @Override
    public List<THiddenTroubleInfo> selectTHiddenTroubleInfoList(THiddenTroubleInfo tHiddenTroubleInfo)
    {
        return tHiddenTroubleInfoMapper.selectTHiddenTroubleInfoList(tHiddenTroubleInfo);
    }

    /**
     * 新增燃气隐患
     *
     * @param tHiddenTroubleInfo 燃气隐患
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor= Exception.class)
    public int insertTHiddenTroubleInfo(THiddenTroubleInfo tHiddenTroubleInfo)
    {
        return tHiddenTroubleInfoMapper.insertTHiddenTroubleInfo(tHiddenTroubleInfo);
    }

    /**
     * 修改燃气隐患
     *
     * @param tHiddenTroubleInfo 燃气隐患
     * @return 结果
     */
    @Override
    public int updateTHiddenTroubleInfo(THiddenTroubleInfo tHiddenTroubleInfo)
    {
        return tHiddenTroubleInfoMapper.updateTHiddenTroubleInfo(tHiddenTroubleInfo);
    }

    /**
     * 批量删除燃气隐患
     *
     * @param hiddenTroubleIds 需要删除的燃气隐患ID
     * @return 结果
     */
    @Override
    public int deleteTHiddenTroubleInfoByIds(Long[] hiddenTroubleIds)
    {
        return tHiddenTroubleInfoMapper.deleteTHiddenTroubleInfoByIds(hiddenTroubleIds);
    }

    /**
     * 删除燃气隐患信息
     *
     * @param hiddenTroubleId 燃气隐患ID
     * @return 结果
     */
    @Override
    public int deleteTHiddenTroubleInfoById(Long hiddenTroubleId)
    {
        return tHiddenTroubleInfoMapper.deleteTHiddenTroubleInfoById(hiddenTroubleId);
    }

    /**
     * Excel数据导出查询接口
     * @param tHiddenTroubleInfo
     * @return
     */
    @Override
    public List<THiddenTroubleInfo> selectTHiddenTroubleInfoExcelList(THiddenTroubleInfo tHiddenTroubleInfo) {
        return tHiddenTroubleInfoMapper.selectTHiddenTroubleInfoExcelList(tHiddenTroubleInfo);
    }
}
